IDATETIME = True

"""PYPIPR Module"""


"""PYTHON Standard Module"""
import datetime


"""PYPI Module"""
import pytz


def datetime_now(timezone=None):
    """
    Datetime pada timezone tertentu
    """
    tz = pytz.timezone(timezone) if timezone else None
    return datetime.datetime.now(tz)



PYPIPR = True

"""PYPIPR Module"""

"""PYTHON Standard Module"""

"""PYPI Module"""


class Pypipr:
    @staticmethod
    def test_print():
        """Print simple text to test this module is working"""
        print("Hello from PyPIPr")
